@@ -8,6 +8,7 @@ import aioredis
 
 from aioredlock.errors import LockError
 from aioredlock.sentinel import Sentinel
+from aioredlock.utility import clean_password
 
 
 class Instance:
@@ -67,7 +68,8 @@ class Instance:
         return logging.getLogger(__name__)
 
     def __repr__(self):
-        return "<%s(connection='%s'>" % (self.__class__.__name__, self.connection)
+        connection_details = clean_password(self.connection)
+        return "<%s(connection='%s'>" % (self.__class__.__name__, connection_details)
 
     @staticmethod
     async def _create_redis_pool(*args, **kwargs):
@@ -265,7 +267,7 @@ class Redis:
         :raises: LockError if the lock has not been set to at least (N/2 + 1)
             instances
         """
-        start_time = time.time()
+        start_time = time.monotonic()
 
         successes = await asyncio.gather(*[
             i.set_lock(resource, lock_identifier, lock_timeout) for
@@ -273,7 +275,7 @@ class Redis:
         ], return_exceptions=True)
         successful_sets = sum(s is None for s in successes)
 
-        elapsed_time = time.time() - start_time
+        elapsed_time = time.monotonic() - start_time
         locked = True if successful_sets >= int(len(self.instances) / 2) + 1 else False
 
         self.log.debug('Lock "%s" is set on %d/%d instances in %s seconds',
@@ -294,7 +296,7 @@ class Redis:
         :raises: LockError if the lock has not matching identifier in more then
             (N/2 - 1) instances
         """
-        start_time = time.time()
+        start_time = time.monotonic()
 
         successes = await asyncio.gather(*[
             i.unset_lock(resource, lock_identifier) for
@@ -302,7 +304,7 @@ class Redis:
         ], return_exceptions=True)
         successful_remvoes = sum(s is None for s in successes)
 
-        elapsed_time = time.time() - start_time
+        elapsed_time = time.monotonic() - start_time
         unlocked = True if successful_remvoes >= int(len(self.instances) / 2) + 1 else False
 
         self.log.debug('Lock "%s" is unset on %d/%d instances in %s seconds',
